@@ -4,9 +4,9 @@
 #include "dylib.h"
 #include "suil_internal.h"
 
-#include "lv2/core/lv2.h"
-#include "lv2/ui/ui.h"
-#include "suil/suil.h"
+#include <lv2/core/lv2.h>
+#include <lv2/ui/ui.h>
+#include <suil/suil.h>
 
 #include <stdbool.h>
 #include <stdint.h>
@@ -17,12 +17,12 @@
 #define GTK2_UI_URI LV2_UI__GtkUI
 #define GTK3_UI_URI LV2_UI__Gtk3UI
 #define QT5_UI_URI LV2_UI__Qt5UI
+#define QT6_UI_URI LV2_UI_PREFIX "Qt6UI"
 #define X11_UI_URI LV2_UI__X11UI
 #define WIN_UI_URI LV2_UI_PREFIX "WindowsUI"
 #define COCOA_UI_URI LV2_UI__CocoaUI
 
-SUIL_API
-unsigned
+SUIL_API unsigned
 suil_ui_supported(const char* host_type_uri, const char* ui_type_uri)
 {
   enum {
@@ -43,7 +43,9 @@ suil_ui_supported(const char* host_type_uri, const char* ui_type_uri)
        !strcmp(ui_type_uri, X11_UI_URI)) ||
       (!strcmp(host_type_uri, QT5_UI_URI) &&
        (!strcmp(ui_type_uri, COCOA_UI_URI) ||
-        !strcmp(ui_type_uri, X11_UI_URI)))) {
+        !strcmp(ui_type_uri, X11_UI_URI))) ||
+      (!strcmp(host_type_uri, QT6_UI_URI) &&
+       (!strcmp(ui_type_uri, X11_UI_URI)))) {
     return SUIL_WRAPPING_EMBEDDED;
   }
 
@@ -84,6 +86,11 @@ open_wrapper(SuilHost*      host,
     module_name = "suil_x11_in_qt5";
   }
 
+  if (!strcmp(container_type_uri, QT6_UI_URI) &&
+      !strcmp(ui_type_uri, X11_UI_URI)) {
+    module_name = "suil_x11_in_qt6";
+  }
+
   if (!strcmp(container_type_uri, QT5_UI_URI) &&
       !strcmp(ui_type_uri, COCOA_UI_URI)) {
     module_name = "suil_cocoa_in_qt5";
@@ -119,8 +126,7 @@ open_wrapper(SuilHost*      host,
   return wrapper;
 }
 
-SUIL_API
-SuilInstance*
+SUIL_API SuilInstance*
 suil_instance_new(SuilHost*                 host,
                   SuilController            controller,
                   const char*               container_type_uri,
@@ -261,8 +267,7 @@ suil_instance_new(SuilHost*                 host,
   return instance;
 }
 
-SUIL_API
-void
+SUIL_API void
 suil_instance_free(SuilInstance* instance)
 {
   if (instance) {
@@ -296,22 +301,19 @@ suil_instance_free(SuilInstance* instance)
   }
 }
 
-SUIL_API
-SuilHandle
+SUIL_API SuilHandle
 suil_instance_get_handle(SuilInstance* instance)
 {
   return instance->handle;
 }
 
-SUIL_API
-LV2UI_Widget
+SUIL_API LV2UI_Widget
 suil_instance_get_widget(SuilInstance* instance)
 {
   return instance->host_widget;
 }
 
-SUIL_API
-void
+SUIL_API void
 suil_instance_port_event(SuilInstance* instance,
                          uint32_t      port_index,
                          uint32_t      buffer_size,
@@ -324,8 +326,7 @@ suil_instance_port_event(SuilInstance* instance,
   }
 }
 
-SUIL_API
-const void*
+SUIL_API const void*
 suil_instance_extension_data(SuilInstance* instance, const char* uri)
 {
   if (instance->descriptor->extension_data) {
