@@ -7,9 +7,9 @@
 #include "dylib.h"
 #include "suil_config.h"
 
-#include "lv2/core/lv2.h"
-#include "lv2/ui/ui.h"
-#include "suil/suil.h"
+#include <lv2/core/lv2.h>
+#include <lv2/ui/ui.h>
+#include <suil/suil.h>
 
 #ifndef _WIN32
 #  include <dlfcn.h>
